Class: Telesign::AutoVerifyClient
- Inherits:
-
RestClient
- Object
- RestClient
- Telesign::AutoVerifyClient
- Defined in:
- lib/telesign/autoverify.rb
Overview
AutoVerify is a secure, lightweight SDK that integrates a frictionless user verification process into existing native mobile applications.
Instance Method Summary collapse
-
#status(external_id, **params) ⇒ Object
Retrieves the verification result for an AutoVerify transaction by external_id.
Methods inherited from RestClient
#delete, generate_telesign_headers, #get, #initialize, #post, #put
Constructor Details
This class inherits a constructor from Telesign::RestClient
Instance Method Details
#status(external_id, **params) ⇒ Object
Retrieves the verification result for an AutoVerify transaction by external_id. To ensure a secure verification flow you must check the status using TeleSign’s servers on your backend. Do not rely on the SDK alone to indicate a successful verification.
See developer.telesign.com/docs/auto-verify-sdk-self#section-obtaining-verification-status for detailed API documentation.
17 18 19 20 21 |
# File 'lib/telesign/autoverify.rb', line 17 def status(external_id, **params) self.get(AUTOVERIFY_STATUS_RESOURCE % {:external_id => external_id}, **params) end |